@@ -19,7 +19,9 @@ def unpack(content):
 	for i in content:
 		if i not in [" "]: format += i
 		else: break
-	return format, content[len(format):]
+	if format == "":
+		raise ValueError("Encrypted format is incorrectly packed.")
+	return format, content[len(format)+1:]
 
 # the symetric aes 254 object class.
 class AES(object):
@@ -480,9 +482,9 @@ class Database(object):
 				if old_format != new_format:
 					return r3sponse.error(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
 				if new_format == "dict":
-					old = Dictionary(self.content)
-					new = Dictionary(path=False, dictionary=old).check(default=default, save=False)
-					if new != old: do = True
+					new = Dictionary(old).check(default=default, save=False)
+					print("NEW:",new,"VS",self.content,"=",new != Dictionary(self.content))
+					if new != Dictionary(self.content): do = True
 				elif new_format == "list":
 					old = list(self.content)
 					new = list(default)
@@ -495,8 +497,8 @@ class Database(object):
 					if new != old: do = True
 				else: return r3sponse.error(f"Unsupported new format: {new_format}.")
 			if do:
-				self.content = Formats.denitialize(new)
-				self.format = Formats.get(self.content, serialize=True)
+				self.content = Formats.initialize(new)
+				self.format = Formats.get(Formats.denitialize(self.content), serialize=True)
 				if save:
 					self.loaded = True
 					response = self.save()
@@ -510,7 +512,7 @@ class Database(object):
 			response = self.aes.decrypt(content.encode())
 			if not response.success: return response
 			decrypted = response.decrypted.decode()
-			if format in ["dict", "list"]:
+			if format in ["dict", "list", "Dictionary", "Array"]:
 				try:
 					content = json.loads(decrypted)
 				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
@@ -527,7 +529,7 @@ class Database(object):
 					content = str(decrypted)
 				except Exception as e: return r3sponse.error(f"Failed to serialize content {self.path}, {e}.")
 			else: return r3sponse.error(f"Unsupported format: {format}.")
-			self.content = Formats.denitialize(content)
+			self.content = Formats.initialize(content)
 			self.format = format
 			self.loaded = True
 			return r3sponse.success(f"Successfully loaded content {self.path}.")
@@ -535,7 +537,7 @@ class Database(object):
 		def save(self):
 			if not self.loaded:
 				return r3sponse.error("The data object is not loaded yet, you must call content.load() first.")
-			if self.format in ["list", "dict"]:
+			if self.format in ["list", "dict", "Dictionary", "Array"]:
 				try:
 					content = json.dumps(Formats.denitialize(self.content))
 				except Exception as e: return r3sponse.error(f"Failed to dump content {self.path}, {e}.")
@@ -546,35 +548,35 @@ class Database(object):
 			response = self.aes.encrypt(content)
 			if not response.success: return response
 			try:
-				content = utils.__save_bytes__(self.path, f"{self.format} ".encode()+response.encrypted)
+				content = utils.__save_bytes__(str(self.path), f"{self.format} ".encode()+response.encrypted)
 			except Exception as e: return r3sponse.error(f"Failed to save content {self.path}, {e}.")
 			return r3sponse.success(f"Successfully saved content {self.path}.")
 		# iterate over self keys & variables.
 		def items(self):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["list"]:
+			if self.format in ["list", "Array"]:
 				return self.content
-			elif self.format in ["dict"]:
+			elif self.format in ["dict", "Dictionary"]:
 				return self.content.items()
 			else:
 				raise ValueError(f"DataObject with format {self.format} does not support the <self.items()> function.")
 		def keys(self):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["list"]:
+			if self.format in ["list", "Array"]:
 				return self.content
-			elif self.format in ["dict"]:
+			elif self.format in ["dict", "Dictionary"]:
 				return list(self.content.keys())
 			else:
 				raise ValueError(f"DataObject with format {self.format} does not support the <self.keys()> function.")
 		def values(self):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict"]:
+			if self.format in ["dict", "Dictionary"]:
 				return list(self.content.values())
 			else:
 				raise ValueError(f"DataObject with format {self.format} does not support the <self.values()> function.")
 		def dict(self, serialize=False):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict"]:
+			if self.format in ["dict", "Dictionary"]:
 				
 				dictionary = {}
 				for key, value in self.content.items():
@@ -591,9 +593,9 @@ class Database(object):
 		# assign self variables by dictionary.
 		def assign(self, dictionary):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if not isinstance(dictionary, dict):
+			if not isinstance(dictionary, (dict, Dictionary)):
 				raise TypeError("You can only self assign with a dictionary as parameter.")
-			if self.format in ["dict"]:
+			if self.format in ["dict", "Dictionary"]:
 				for key,value in dictionary.items():
 					self.content[key] = value
 			else:
@@ -601,9 +603,9 @@ class Database(object):
 		# count items.
 		def __len__(self):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["list"]:
+			if self.format in ["list", "Array"]:
 				return len(self.content)
-			elif self.format in ["dict"]:
+			elif self.format in ["dict", "Dictionary"]:
 				return len(self.content.keys())
 			elif self.format in ["str", "int", "float"]:
 				return len(str(self.content))
@@ -612,7 +614,7 @@ class Database(object):
 		# support item assignment.
 		def __setitem__(self, key, value):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict"]:
+			if self.format in ["dict", "Dictionary"]:
 				setattr(self.content, key, value)
 			elif self.format in ["str"] and isinstance(key, (int, Integer)):
 				self.content[int(key)] = value
@@ -620,7 +622,7 @@ class Database(object):
 				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
 		def __getitem__(self, key):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict"]:
+			if self.format in ["dict", "Dictionary"]:
 				return getattr(self.content, key)
 			elif self.format in ["str"] and isinstance(key, (int, Integer)):
 				return self.content[int(key)]
@@ -628,7 +630,7 @@ class Database(object):
 				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
 		def __delitem__(self, key):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict"]:
+			if self.format in ["dict", "Dictionary"]:
 				delattr(self.content, key)
 			else:
 				raise ValueError(f"DataObject with format {self.format} does not support the self[""] item assignment.")
@@ -645,7 +647,7 @@ class Database(object):
 				return f"<encrypti0n.aes.Database.DataObject {self.path} content: {self.content}>"
 		def json(self,):
 			if not self.loaded: raise ValueError("Load the content object first.")
-			if self.format in ["dict"]:
+			if self.format in ["dict", "Dictionary"]:
 				return self.dict(serialize=True)
 			else:
 				raise ValueError(f"DataObject with format {self.format} does not support the <self.json()> function.")
